MobilePlayerController class

Inheritance

Constructors

MobilePlayerController({required MediaKitBackgroundPlayer audioHandler})

Properties

audioHandler → MediaKitBackgroundPlayer
final
currentImage → ValueNotifier<String>
finalinherited
currentSongTitle → ValueNotifier<String>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
idGen → Random
final
isFirstSong → ValueNotifier<bool>
finalinherited
isLastSong → ValueNotifier<bool>
finalinherited
isStopped → ValueNotifier<bool>
finalinherited
playbackSpeed → ValueNotifier<double>
finalinherited
playButton → ValueNotifier<ButtonState>
finalinherited
progressState → ValueNotifier<ProgressBarState>
finalinherited
queue → ValueNotifier<List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
override
init() → void
loadMedia(List<MediaRecord> input, {Duration listenedPos = Duration.zero, int trackIndex = 0}) → Future<void>
Use this to load your data in
override
next() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<void>
override
play() → Future<void>
override
previous() → Future<void>
override
seek(Duration position, {int? trackIndex}) → Future<void>
override
seekBackward(Duration positionOffset) → Future<void>
override
seekForward(Duration positionOffset) → Future<void>
override
setSpeed() → Future<void>
override
skipToTrack({Duration position = Duration.zero, int trackIndex = 0}) → Future<void>
override
stop() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited