DefaultMetadata class

Define default metadata to display e.g. default image or title

Constructors

DefaultMetadata({required String defaultImage, required String defaultTitle})

Properties

defaultImage → String
final
defaultTitle → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited