PlayerInterface class abstract

Implementers

Constructors

PlayerInterface()

Properties

currentImage → ValueNotifier<String>
final
currentSongTitle → ValueNotifier<String>
final
hashCode → int
The hash code for this object.
no setterinherited
isFirstSong → ValueNotifier<bool>
final
isLastSong → ValueNotifier<bool>
final
isStopped → ValueNotifier<bool>
final
playbackSpeed → ValueNotifier<double>
final
playButton → ValueNotifier<ButtonState>
final
progressState → ValueNotifier<ProgressBarState>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
loadMedia(List<MediaRecord> input, {Duration listenedPos = Duration.zero, int trackIndex = 0}) → Future<void>
Use this to load your data in
next() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<void>
play() → Future<void>
previous() → Future<void>
seek(Duration position) → Future<void>
seekBackward(Duration positionOffset) → Future<void>
seekForward(Duration positionOffset) → Future<void>
setSpeed() → Future<void>
skipToTrack({Duration position = Duration.zero, int trackIndex = 0}) → Future<void>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited