ProgressBarState class

Constructors

ProgressBarState({required Duration current, required Duration buffered, required Duration total})
const

Properties

buffered → Duration
final
current → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → Duration
final

Methods

copyWith({Duration? current, Duration? buffered, Duration? total}) → ProgressBarState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited